// FilterDlg.cpp :      CFilterDlg
// (C) Red User, 2004
// mailto:reduser@nm.ru

#include "stdafx.h"
#include "Filter.h"
#include "Filt.h"
#include "FilterDlg.h"
#include ".\filterdlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

CFilterDlg::CFilterDlg(CWnd* pParent)
	: CDialog(CFilterDlg::IDD, pParent)
    , m_strSrcFileName(_T(""))
    , m_strDestFileName(_T(""))
    , m_strCondF(_T(""))
    , m_strCondL(_T(""))
    , m_strCondB(_T(""))
    , m_bCheckFromTo(FALSE)
    , m_bCheckFromToEnd(FALSE)
    , m_bCheckMaxEmpty(FALSE)
    , m_iMaxEmpty(0)
{
    m_hIcon = AfxGetApp()->LoadStandardIcon(IDI_APPLICATION);
}

void CFilterDlg::DoDataExchange(CDataExchange* pDX)
{
    CDialog::DoDataExchange(pDX);
    DDX_Text(pDX, IDC_EDIT_SRC, m_strSrcFileName);
    DDX_Text(pDX, IDC_EDIT_DEST, m_strDestFileName);
    DDX_Text(pDX, IDC_EDIT_COND_F, m_strCondF);
    DDX_Text(pDX, IDC_EDIT_COND_L, m_strCondL);
    DDX_Text(pDX, IDC_EDIT_COND_B, m_strCondB);
    DDX_Check(pDX, IDC_CHECK_FROMTO, m_bCheckFromTo);
    DDX_Check(pDX, IDC_CHECK_FROMTOEND, m_bCheckFromToEnd);
    DDX_Check(pDX, IDC_CHECK_MAXEMPTY, m_bCheckMaxEmpty);
    DDX_Text(pDX, IDC_EDIT_MAXEMPTY, m_iMaxEmpty);
	DDV_MinMaxInt(pDX, m_iMaxEmpty, 0, INT_MAX / 10);
}

BEGIN_MESSAGE_MAP(CFilterDlg, CDialog)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
    ON_BN_CLICKED(IDRUN, OnBnClickedRun)
    ON_BN_CLICKED(IDC_BUTTON_BROWSESRC, OnBnClickedBrowseSrc)
    ON_BN_CLICKED(IDC_BUTTON_BROWSEDEST, OnBnClickedBrowseDest)
    ON_BN_CLICKED(IDC_CHECK_FROMTO, OnBnClickedCheckFromTo)
    ON_BN_CLICKED(IDC_CHECK_FROMTOEND, OnBnClickedCheckFromToEnd)
    ON_BN_CLICKED(IDC_CHECK_MAXEMPTY, OnBnClickedCheckMaxEmpty)
END_MESSAGE_MAP()

BOOL CFilterDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	return TRUE;  // return TRUE  unless you set the focus to a control
}

void CFilterDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CFilterDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}

void CFilterDlg::OnBnClickedRun()
{
    const int iMaxSize = 0x20000;
    ULONGLONG ullSize;
    int iSize;
    void *pBuf;

    try
    {
        CWaitCursor wait;
        if (!UpdateData(TRUE))
        {
            m_iMaxEmpty = 0;
            UpdateData(FALSE);
            return;
        }
        ASSERT(m_iMaxEmpty >= 0);
        CFile fSrc(m_strSrcFileName, CFile::modeRead|CFile::shareDenyWrite);        
        ullSize = fSrc.GetLength();
        if (ullSize <= iMaxSize)
        {
            iSize = (int)ullSize;
            CFile fDest(m_strDestFileName, CFile::modeCreate|CFile::modeWrite|CFile::shareDenyWrite);
            //      
            pBuf = new char[iSize/*2000000000*/];
            CFilt filt;
            fSrc.Read(pBuf, iSize);
            fSrc.Close();
            if (m_bCheckFromTo) 
                filt.DelFromTo(m_strCondF, m_strCondL); 
            if (m_bCheckFromToEnd)
                filt.DelFromToEnd(m_strCondB);
            if (m_bCheckMaxEmpty)
                filt.SetMaxEmpty(m_iMaxEmpty);
            filt.Run((LPTSTR)pBuf, iSize);
            fDest.Write(pBuf, iSize);
            delete [] pBuf;
        }
        else
            MessageBox(_T("  ."));        
    }
    catch (CException* perr)
    {
        perr->ReportError();
        perr->Delete();
    }
}

void CFilterDlg::OnBnClickedBrowseSrc()
{
    Browse(m_strSrcFileName, IDC_EDIT_SRC);
}

void CFilterDlg::OnBnClickedBrowseDest()
{
    Browse(m_strDestFileName, IDC_EDIT_DEST);
}

void CFilterDlg::OnBnClickedCheckFromTo()
{
    EnblDisbl(IDC_EDIT_COND_F);
    EnblDisbl(IDC_EDIT_COND_L);
}

void CFilterDlg::OnBnClickedCheckFromToEnd()
{
    EnblDisbl(IDC_EDIT_COND_B);
}

void CFilterDlg::OnBnClickedCheckMaxEmpty()
{
    EnblDisbl(IDC_EDIT_MAXEMPTY);
    SetDlgItemText(IDC_EDIT_MAXEMPTY, _T("0"));
}

void CFilterDlg::Browse(CString &strFullFileName, int nID)
{
    CFileDialog brws(TRUE);
    brws.m_ofn.lpstrTitle = _T("Filter");
    brws.m_ofn.Flags |= OFN_ENABLESIZING;
    brws.m_ofn.lpstrFilter =
        _T(" \0*.*\0")
        _T(" HTML\0*.htm;*.html\0")
        _T(" \0*.txt\0");
    if (brws.DoModal() == IDOK)
        strFullFileName = brws.GetPathName();
    SetDlgItemText(nID, strFullFileName);
}

void CFilterDlg::EnblDisbl(int nID)
{
    CWnd *pWnd = GetDlgItem(nID);
    ASSERT(pWnd);
    pWnd->EnableWindow(!(pWnd->IsWindowEnabled()));
}
